#
# spec file for package jing-trang
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jing-trang
Version:        20220510
Release:        5.6
Summary:        Schema validation and conversion based on RELAX NG
License:        BSD-3-Clause
Group:          Productivity/Text/Utilities
URL:            https://github.com/relaxng/%{name}
Source0:        %{name}-%{version}.tar.xz
Source1:        https://repo1.maven.org/maven2/org/relaxng/jing/%{version}/jing-%{version}.pom
Source2:        https://repo1.maven.org/maven2/org/relaxng/trang/%{version}/trang-%{version}.pom
Source10:       dtdinst.1
#
Patch0:         0000-Various-build-fixes.patch
Patch2:         no-tests.patch
Patch3:         old-saxon.patch
BuildRequires:  ant >= 1.8.2
#
BuildRequires:  bsh2
BuildRequires:  fdupes
BuildRequires:  isorelax
BuildRequires:  java-devel >= 1.8
BuildRequires:  javacc
BuildRequires:  javapackages-local >= 6
BuildRequires:  qdox
BuildRequires:  relaxngDatatype >= 2011.1
BuildRequires:  saxon10
BuildRequires:  unzip
BuildRequires:  xalan-j2
BuildRequires:  xml-commons-apis
BuildRequires:  xml-commons-resolver
#
BuildArch:      noarch

%description
%{summary}:

jing:  Schema validator
trang: Multi-format schema converter

%package     -n jing
Summary:        RELAX NG validator in Java
Group:          Productivity/Text/Utilities
Requires:       java-headless
Requires:       jpackage-utils
Requires:       mvn(com.github.relaxng:relaxngDatatype) >= 2011.1
Requires:       mvn(xml-resolver:xml-resolver)
Provides:       mvn(com.thaiopensource:jing)
Provides:       mvn(org.relaxng:jing) = %{version}

%description -n jing
jing is an XML validator implemented in Java. It validates against the
RELAX NG schema language and implements the following specifications:

* RELAX NG 1.0 Specification
* RELAX NG Compact Syntax
* Parts of RELAX NG DTD Compatibility (checking of ID/IDREF/IDREFS)

It also comes with experimental support for schema languages other than
RELAX NG:

* W3C XML Schema (based on Xerces-J)
* Schematron 1.5
* Namespace Routing Language

%package     -n jing-javadoc
Summary:        Javadoc API documentation for Jing
Group:          Documentation/HTML

%description -n jing-javadoc
Javadoc API documentation for Jing.

%package     -n trang
Summary:        Multi-format schema converter based on RELAX NG
Group:          Productivity/Text/Utilities
Requires:       java-headless
Requires:       jpackage-utils
Requires:       mvn(com.github.relaxng:relaxngDatatype) >= 2011.1
Requires:       mvn(xerces:xercesImpl)
Requires:       mvn(xml-resolver:xml-resolver)
Provides:       mvn(com.thaiopensource:trang)
Provides:       mvn(org.relaxng:trang) = %{version}

%description -n trang
Trang converts between different schema languages for XML.  It supports the
following languages: RELAX NG (both XML and compact syntax), XML 1.0 DTDs, W3C
XML Schema.  A schema written in any of the supported schema languages can be
converted into any of the other supported schema languages, except that W3C XML
Schema is supported for output only, not for input.

%package     -n dtdinst
Summary:        XML DTD to XML instance format converter
Group:          Productivity/Text/Utilities
Requires:       java-headless
Requires:       jpackage-utils

%description -n dtdinst
DTDinst is a program for converting XML DTDs into an XML instance format.

%prep
%setup -q

cp %{SOURCE1} jing.pom
cp %{SOURCE2} trang.pom
cp %{SOURCE10} .
mv gcj/{trang,jing}.1 .

%patch -P 0 -p1
%patch -P 2 -p1
%patch -P 3 -p1
rm -f \
  mod/schematron/src/main/com/thaiopensource/validate/schematron/OldSaxonSchemaReaderFactory.java
sed -i -e 's/\r//g' lib/isorelax.copying.txt
sed -i -e 's|"\(copying\.txt\)"|"%{_licensedir}/dtdinst/\1"|' \
    dtdinst/index.html
sed -i -e 's|"\(copying\.txt\)"|"%{_licensedir}/trang/\1"|' \
    trang/doc/trang.html trang/doc/trang-manual.html

%build
CLASSPATH=$(build-classpath \
    xalan-j2 xalan-j2-serializer xerces-j2 xml-commons-apis \
	saxon10 relaxngDatatype) \
%{ant} \
	-Dlib.dir=%{_javadir} -Dbuild.sysclasspath=last \
	-Dant.build.javac.source=8 -Dant.build.javac.target=8 \
	dist

%install
install -dm 0755 %{buildroot}{%{_mandir}/man1,%{_javadocdir}}

unzip build/dist/jing-%{version}.zip
unzip build/dist/trang-%{version}.zip
unzip build/dist/dtdinst-%{version}.zip
rm -f jing-%{version}/sample/datatype/datatype-sample.jar

# JAR artifacts
install -dm 0755 %{buildroot}%{_javadir}
install -dm 0755 %{buildroot}%{_mavenpomdir}

install -pm 0644 jing-%{version}/bin/jing.jar %{buildroot}%{_javadir}/jing.jar
%mvn_install_pom jing.pom %{buildroot}%{_mavenpomdir}/jing.pom
%add_maven_depmap jing.pom jing.jar -f jing

install -pm 0644 trang-%{version}/trang.jar %{buildroot}%{_javadir}/trang.jar
%mvn_install_pom trang.pom  %{buildroot}%{_mavenpomdir}/trang.pom
%add_maven_depmap trang.pom trang.jar -f trang

install -pm 0644 dtdinst-%{version}/dtdinst.jar %{buildroot}%{_javadir}/dtdinst.jar
%add_maven_depmap org.relaxng:dtdinst:%{version} dtdinst.jar -f dtdinst

# API cocumentation
mv jing-%{version}/doc/api %{buildroot}%{_javadocdir}/jing
%fdupes %{buildroot}%{_javadocdir}

# We need to redefine name here to make jpackage_script aware of
# the correct name, otherwise it would use "jing-trang" in configuration names etc.
%define name jing
%jpackage_script com.thaiopensource.relaxng.util.Driver "" "" jing:relaxngDatatype:xml-commons-resolver:xerces-j2 jing true
mkdir -p jing-%{version}/_licenses
mv jing-%{version}/doc/*copying.* jing-%{version}/_licenses

%define name trang
%jpackage_script com.thaiopensource.relaxng.translate.Driver "" "" trang:relaxngDatatype:xml-commons-resolver:xerces-j2 trang true

%define name dtdinst
%jpackage_script com.thaiopensource.xml.dtd.app.Driver "" "" dtdinst dtdinst true

# Install manpages and replace @VERSION@
install -Dm0644 {dtdinst,jing,trang}.1 %{buildroot}%{_mandir}/man1/
sed -i 's/@VERSION@/%{version}/g' %{buildroot}%{_mandir}/man1/*.1

%files -n jing -f .mfiles-jing
%license jing-%{version}/_licenses/*
%doc jing-%{version}/{readme.html,doc,sample}
%{_mandir}/man1/jing.1%{?ext_man}
%{_bindir}/jing

%files -n jing-javadoc
%{_javadocdir}/jing
%license jing-%{version}/_licenses/*

%files -n trang -f .mfiles-trang
%license trang-%{version}/copying.txt
%doc trang-%{version}/*.html
%{_bindir}/trang
%{_mandir}/man1/trang.1%{?ext_man}

%files -n dtdinst -f .mfiles-dtdinst
%license dtdinst-%{version}/copying.txt
%doc dtdinst-%{version}/*.{html,rng,xsl}
%doc dtdinst-%{version}/{dtdinst.rnc.txt,teixml.dtd.txt,example}
%{_bindir}/dtdinst
%{_mandir}/man1/dtdinst.1%{?ext_man}

%changelog
* Wed Feb 21 2024 Gus Kenion <gus.kenion@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Aug 15 2023 Fridrich Strba <fstrba@suse.com>
- Build against saxon 10+
* Mon Mar 20 2023 Fridrich Strba <fstrba@suse.com>
- Fetch the sources using the source service and filter out stray
  binaries and other files that we don't want to distribute because
  of licensing.
* Sat Jan 21 2023 Thomas Schraitle <thomas.schraitle@suse.com>
- Add Maven Provides line for Jing & Trang
* Mon Jul 25 2022 Thomas Schraitle <thomas.schraitle@suse.com>
- Update to 20220510
- Removed patch:
  * 0002-Use-Xalan-instead-of-Saxon-for-the-build-655601.patch
    Use Saxon9 instead of Xalan
- Recreated patch files
* Fri Jul  2 2021 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * old-saxon.patch
    + Avoid building old saxon validator in order to avoid
    dependency on old saxon6
* Fri Jul  2 2021 Fridrich Strba <fstrba@suse.com>
- Do not use xmvn-tools, since this is a ring package
- Added patch:
  * no-tests.patch
    + avoid unnecessary dependency on testng
* Sun Jun 27 2021 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v20181222
- Package maven metadata
- Use testng in build process
- Remove unneeded patches:
  * jing-trang-20091111-datatype-sample.patch
  * jing-trang-20151127-notestng.patch
- Modified patch:
  * 0001-Various-build-fixes.patch -> 0000-Various-build-fixes.patch
* Fri Dec  7 2018 Fridrich Strba <fstrba@suse.com>
- Build against xml-commons-apis instead of xerces-j2-xml-apis
* Thu Nov  1 2018 Fridrich Strba <fstrba@suse.com>
- Change to build against bsh2 instead of the old bsh
* Fri Dec  1 2017 thomas.schraitle@suse.com
- Fix bsc#1069796 to combine jing and trang into a single jing-trang
  source package
* Wed Nov 15 2017 thomas.schraitle@suse.com
- First attempt to combine jing and trang packages into a
  single package on OBS
- Use patches and instructions from Fedora, but use %%buildroot
  instead of $RPM_BUILD_ROOT
- Install manpages for dtdinst, jing, and trang
- Use spec-cleaner
* Tue Nov 14 2017 toms@opensuse.org
- Use saxon9 instead of saxon6 for jing script
- Apply spec-cleaner for spec file
* Mon Jan 26 2015 toms@opensuse.org
- Fixed name of saxon jar [bsc#914681]
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Thu Nov 29 2012 mvyskocil@suse.com
- used saxon9 for build and as a dependency (bnc#780666)
* Sun Nov 13 2011 toms@opensuse.org
- Improved jing script: use now jpackage-utils, added
  xml-commons-resolver to better support catalogs
- Adapted requires and buildrequires in spec file
- Updated documentation
  * explained -C and -s options, removed obsolete -f
  * updated version
* Mon Mar 15 2010 prusnak@suse.cz
- updated to 20091111
  * add -C option to specify the catalog
  * fix schematron test suite schema
  * provide a resolver that implements OASIS XML catalogs
  * take advantage of Java 5 features
* Wed Mar 18 2009 prusnak@suse.cz
- added documentation (manpage) by Thomas Schraitle
* Thu Nov 27 2008 prusnak@suse.cz
- updated to 20081028
* Tue Feb 19 2008 prusnak@suse.cz
- fixed build
* Thu Mar 29 2007 rguenther@suse.de
- add unzip BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jun  6 2005 ke@suse.de
- Add wrapper script; proposed by Martin Vidner.
* Fri Jun  3 2005 ke@suse.de
- New package: jing version 20030619.
